## 约定
以下为Pywander本模块和使用Pywander模块情景下应该考虑的约定。

### 日期时间
约定dt前缀表示python的datetime object.

约定任何时间获取在没有特别说明时区的情况下均为 utc时区.

约定时间戳指的是Unix时间戳, 即 1730693803 这样的整数秒数. 时间戳默认UTC时区.

### 文件路径
约定对外返回的路径均为字符串类型, Path对象有时把问题弄复杂了, 只供内部使用.

### json文件
没有特殊理由的情况下，应该约定json文件内部格式为：
```
{
key1: value1,
key2: value2
}
```
这样的格式已经具有了完备的数据表达和存储可能性，再引入其他结构只会引来混乱。

### 配置
明了胜过隐晦，除了极个别的私密配置，其他所有配置请在程序文件开头明明白白地声明出来，如果觉得太多了可以放在另外一个 `config.py`文件下，这个
`config.py` 文件下面简称为配置文件。

私密配置请参考 `.env` 环境变量的那一套做法。

所有配置的key为大写字母形式，不得以下划线开头。

配置加载之后的实际效果和在代码开头声明的效果应该是等同的。

配置文件默认在  `os.path.join('~', 'Pywander', app_name, 'config.py')` 如果找不到则不进行更新动作。

### 缓存
缓存文件默认在 `os.path.join('~', 'Pywander', app_name, 'cachedb')` .

### 数据集
数据集文件默认在 `os.path.join('~', 'Pywander', app_name, 'datasets')`

### 模型
模型文件默认在 `os.path.join('~', 'Pywander', app_name, 'models')`

### 应用名app_name
用户对应用名的唯一性负全责，如果脚本没有指定应用名，那么默认的应用名为 `test` .



### 线性代数
#### 行向量和列向量和1d_array
一般应用场景是不需要确立所谓数学意义上严格的行向量和列向量的，但在某些情景下，要求实现列向量和行向量的点积输出是一个矩阵，这个时候行向量和列向量和1d_array
都需要严格进行区分，如下所示：

- 1d array:  np.array([1, 2, 3])
- row_vector  np.array([[1,2,3]])
- col vector np.array([[2],[0],[0]])

